@@ -2,8 +2,6 @@
     BangPatterns,
     CPP,
     DefaultSignatures,
-    DataKinds,
-    PolyKinds,
     FlexibleContexts,
     FlexibleInstances,
     KindSignatures,
@@ -15,6 +13,11 @@
     UndecidableInstances
     #-}
 
+#if __GLASGOW_HASKELL__ >= 800
+{-# LANGUAGE DataKinds #-}
+{-# LANGUAGE PolyKinds #-}
+#endif
+
 module Data.Csv.Conversion
     (
     -- * Type conversion
